==> fuioupay-sdk-1.0.0.20241114-20241107.174234-1-sources.jar: com/fshows/fuiou/client/impl/FuiouFgjSignerImpl.java <==
/**
 * fshows.com
 * Copyright (C) 2013-2023 All Rights Reserved.
 */
package com.fshows.fuiou.client.impl;

import cn.hutool.core.util.StrUtil;
import cn.hutool.crypto.digest.MD5;
import com.fshows.fuiou.client.base.ApiClientConfig;
import com.fshows.fuiou.client.base.ISigner;
import com.fshows.fuiou.client.base.SignParam;
import com.fshows.fuiou.client.base.VerifySignParam;
import com.fshows.fuiou.exception.FuiouApiException;
import com.fshows.fuiou.request.base.FuiouBizRequest;
import com.fshows.fuiou.util.FuiouRequestUtils;
import com.fshows.fuiou.util.LogUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.StringUtils;

import java.util.Map;
import java.util.TreeMap;

/**
 * @author zhubo
 * @version MerchantSignerImpl.java, v 0.1 2023-09-11 17:02 zhubo
 */
@Slf4j
public class FuiouFgjSignerImpl implements ISigner {
    /**
     * 获取待加签字符串，格式：addn_inf=&curr_type=&goods_des=卡盟测试&goods_detail=asasda&goods_tag=&ins_cd=08A9999999&
     *
     * @return
     */
    public static String getWaitSignStr(Map<String, String> dataMap, ApiClientConfig apiClientConfig) {
        StringBuilder sb = new StringBuilder();
        for (Map.Entry<String, String> entry : dataMap.entrySet()) {
            String key = entry.getKey();
            String value = entry.getValue();
            if (StringUtils.equals(key, "sign")
                    || StringUtils.startsWith(key, "reserved")
                    || StringUtils.equals(key, "bene_infos")
                    || StringUtils.equals(key, "shareholder_infos")
                    || StringUtils.equals(key, "bene_img_ids")
                    || StringUtils.equals(key, "sharehold_img_ids")) {
                continue;
            }
            if (StrUtil.isBlank(value)) {
                continue;
            }
            if (sb.length() > 0) {
                sb.append("&");
            }
            sb.append(key).append("=").append(value);
        }
        sb.append("&key=").append(apiClientConfig.getFuiouMerchantPrivateKey());
        return sb.toString();
    }

    public static void main(String[] args) {
        ApiClientConfig apiClientConfig = new ApiClientConfig();
        apiClientConfig.setFuiouMerchantPrivateKey("040f23510fbf4b34ae3895272e83c58c");
        String privateKey = "040f23510fbf4b34ae3895272e83c58c";

        Map<String, String> map = new TreeMap<>();
        map.put("name", "111111");
        map.put("age", "222222");
        String waitSignStr = getWaitSignStr(map, apiClientConfig);
        System.out.println(waitSignStr + "\n\n\n");
        // 创建加签对象
        String digestHex = MD5.create().digestHex(waitSignStr);
        System.out.println(digestHex);
        map.put("sign", digestHex);
        System.out.println("\n\n\n" + FuiouRequestUtils.generateXml(map));
    }

    @Override
    public String sign(SignParam signParam, ApiClientConfig apiClientConfig) throws FuiouApiException {
        return doSign(signParam, apiClientConfig);
    }

    @Override
    public Boolean verifySign(Map<String, String> resMap, VerifySignParam verifySignParam, ApiClientConfig apiClientConfig) throws FuiouApiException {
        try {
            // 获取待加签字符串
            String waitSignStr = getWaitSignStr(resMap, apiClientConfig);
            // 响应签名
            String resSign = resMap.get("sign");
            //加签
            return resSign.equals(getWaitSignStr(resMap, apiClientConfig));
        } catch (Exception e) {
            LogUtil.error(log, "【fuiou-sdk】fuiou响应结果验签失败 >> signParam={}", e, verifySignParam);
            throw new FuiouApiException("fuiou响应结果验签失败", e);
        }
    }

    /**
     * 执行方法加签
     *
     * @param signParam
     * @param apiClientConfig
     * @return
     * @throws FuiouApiException
     */
    public String doSign(SignParam signParam, ApiClientConfig apiClientConfig) throws FuiouApiException {
        try {
            FuiouBizRequest request = signParam.getRequest();
            // 获取待加签字符串
            Map<String, String> data = FuiouRequestUtils.toMap(request, apiClientConfig.isHump());
            // 获取待加签字符串
            String waitSignStr = getWaitSignStr(data, apiClientConfig);
            LogUtil.info(log, "【fuiou-sdk】待加签字符串 >> waitSignStr={}", waitSignStr);
            //加签
            String md5Hex = DigestUtils.md5Hex(waitSignStr.getBytes(apiClientConfig.getCharset()));
            return md5Hex.toLowerCase();
        } catch (Exception e) {
            LogUtil.error(log, "【fuiou-sdk】fuiou请求加签失败 >> signParam={}", e, signParam);
            throw new FuiouApiException("请求加签失败", e);
        }
    }
}

==> fuioupay-sdk-1.0.0.20251023.01-20251021.030644-1-sources.jar: com/fshows/fuiou/client/impl/FuiouFgjSignerImpl.java <==
/**
 * fshows.com
 * Copyright (C) 2013-2023 All Rights Reserved.
 */
package com.fshows.fuiou.client.impl;

import cn.hutool.core.util.StrUtil;
import cn.hutool.crypto.digest.MD5;
import com.fshows.fuiou.client.base.ApiClientConfig;
import com.fshows.fuiou.client.base.ISigner;
import com.fshows.fuiou.client.base.SignParam;
import com.fshows.fuiou.client.base.VerifySignParam;
import com.fshows.fuiou.exception.FuiouApiException;
import com.fshows.fuiou.request.base.FuiouBizRequest;
import com.fshows.fuiou.util.FuiouRequestUtils;
import com.fshows.fuiou.util.LogUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.StringUtils;

import java.util.Map;
import java.util.TreeMap;

/**
 * @author zhubo
 * @version MerchantSignerImpl.java, v 0.1 2023-09-11 17:02 zhubo
 */
@Slf4j
public class FuiouFgjSignerImpl implements ISigner {
    /**
     * 获取待加签字符串，格式：addn_inf=&curr_type=&goods_des=卡盟测试&goods_detail=asasda&goods_tag=&ins_cd=08A9999999&
     *
     * @return
     */
    public static String getWaitSignStr(Map<String, String> dataMap, ApiClientConfig apiClientConfig) {
        StringBuilder sb = new StringBuilder();
        for (Map.Entry<String, String> entry : dataMap.entrySet()) {
            String key = entry.getKey();
            String value = entry.getValue();
            if (StringUtils.equals(key, "sign")
                    || StringUtils.startsWith(key, "reserved")
                    || StringUtils.equals(key, "bene_infos")
                    || StringUtils.equals(key, "shareholder_infos")
                    || StringUtils.equals(key, "bene_img_ids")
                    || StringUtils.equals(key, "sharehold_img_ids")) {
                continue;
            }
            if (StrUtil.isBlank(value)) {
                continue;
            }
            if (sb.length() > 0) {
                sb.append("&");
            }
            sb.append(key).append("=").append(value);
        }
        sb.append("&key=").append(apiClientConfig.getFuiouMerchantPrivateKey());
        return sb.toString();
    }

    public static void main(String[] args) {
        ApiClientConfig apiClientConfig = new ApiClientConfig();
        apiClientConfig.setFuiouMerchantPrivateKey("040f23510fbf4b34ae3895272e83c58c");
        String privateKey = "040f23510fbf4b34ae3895272e83c58c";

        Map<String, String> map = new TreeMap<>();
        map.put("name", "111111");
        map.put("age", "222222");
        String waitSignStr = getWaitSignStr(map, apiClientConfig);
        System.out.println(waitSignStr + "\n\n\n");
        // 创建加签对象
        String digestHex = MD5.create().digestHex(waitSignStr);
        System.out.println(digestHex);
        map.put("sign", digestHex);
        System.out.println("\n\n\n" + FuiouRequestUtils.generateXml(map));
    }

    @Override
    public String sign(SignParam signParam, ApiClientConfig apiClientConfig) throws FuiouApiException {
        return doSign(signParam, apiClientConfig);
    }

    @Override
    public Boolean verifySign(Map<String, String> resMap, VerifySignParam verifySignParam, ApiClientConfig apiClientConfig) throws FuiouApiException {
        try {
            // 获取待加签字符串
            String waitSignStr = getWaitSignStr(resMap, apiClientConfig);
            // 响应签名
            String resSign = resMap.get("sign");
            //加签
            return resSign.equals(getWaitSignStr(resMap, apiClientConfig));
        } catch (Exception e) {
            LogUtil.error(log, "【fuiou-sdk】fuiou响应结果验签失败 >> signParam={}", e, verifySignParam);
            throw new FuiouApiException("fuiou响应结果验签失败", e);
        }
    }

    /**
     * 执行方法加签
     *
     * @param signParam
     * @param apiClientConfig
     * @return
     * @throws FuiouApiException
     */
    public String doSign(SignParam signParam, ApiClientConfig apiClientConfig) throws FuiouApiException {
        try {
            FuiouBizRequest request = signParam.getRequest();
            // 获取待加签字符串
            Map<String, String> data = FuiouRequestUtils.toMap(request, apiClientConfig.isHump());
            // 获取待加签字符串
            String waitSignStr = getWaitSignStr(data, apiClientConfig);
            LogUtil.debug(log, "【fuiou-sdk】待加签字符串 >> waitSignStr={}", waitSignStr);
            //加签
            String md5Hex = DigestUtils.md5Hex(waitSignStr.getBytes(apiClientConfig.getCharset()));
            return md5Hex.toLowerCase();
        } catch (Exception e) {
            LogUtil.error(log, "【fuiou-sdk】fuiou请求加签失败 >> signParam={}", e, signParam);
            throw new FuiouApiException("请求加签失败", e);
        }
    }
}
